/*
 * Copyright Johannes Sixt
 * This file is licensed under the GNU General Public License Version 2.
 * See the file COPYING in the toplevel directory of the source directory.
 */

#ifndef COMMANDIDS_H
#define COMMANDIDS_H

// statusbar ids
#define ID_STATUS_MSG 191
#define ID_STATUS_ACTIVE 193
#endif // COMMANDIDS_H
